==> landers.angular-2.0.69.tgz: package/src/control/directive-money.js <==
;angular.module('Landers.angular')
    .directive('money', ['Flat', '$compile', '$filter', function(Flat, $compile, $filter){
        Landers.css.add('.cny:after {content:"￥"}');
        return {
            restrict : 'E',
            link : function($scope, $ele, $attrs) {
                var key = $attrs['amount'];
                var show = function(key, amount){
                    var ui_sref = $attrs['uiSref'];

                    if (amount) Flat.set($scope, key, parseFloat(amount.toFixed(2)));

                    Flat.set($scope, '$runtime.directive.money.amount', amount);
                    Flat.set($scope, '$runtime.directive.money.cny', amount > 0);
                    Flat.set($scope, '$runtime.directive.money.unit', $attrs['unit'] || '' );
                    Flat.set($scope, '$runtime.directive.money.a', !!ui_sref);
                    Flat.set($scope, '$runtime.directive.money.span', !ui_sref);
                    Flat.set($scope, '$runtime.directive.money.ifClass', !isNaN(amount));
                    var if_class = "{'" + $attrs['class'] + "': $runtime.directive.money.ifClass}";

                    var html = '';
                    html += '<span>';
                    html += '   <em class="cny" ng-show="$runtime.directive.money.cny"></em>';
                    html += '   <span class="amount" ng-if="$runtime.directive.money.a" ng-class="' + if_class+ '" ng-bind-html="' + key + '"></span>';
                    html += '   <span class="amount" ng-if="$runtime.directive.money.span" ng-class="' + if_class+ '" ng-bind-html="' + key + '"></span>';
                    html += '   <em class="unit-cny" ng-show="$runtime.directive.money.unit">{{$runtime.directive.money.unit}}</em>';
                    html += '</span>';

                    $ele.replaceWith($compile(html)($scope));
                }

                $scope.$watch(key, function(new_value){
                    show(key, Number(new_value));
                });

            }
        };
    }]);

==> landers.angular-2.0.77.tgz: package/src/control/directive-money.js <==
;angular.module('Landers.angular')
    .directive('money', ['Flat', '$compile', '$filter', function(Flat, $compile, $filter){
        Landers.css.add('.cny:after {content:"￥"}');
        return {
            restrict : 'E',
            link : function($scope, $ele, $attrs) {
                var key = $attrs['amount'];
                var show = function(key, amount){
                    var ui_sref = $attrs['uiSref'];

                    if (amount) Flat.set($scope, key, parseFloat(amount.toFixed(2)));

                    Flat.set($scope, '$runtime.directive.money.amount', amount);
                    Flat.set($scope, '$runtime.directive.money.cny', amount > 0);
                    Flat.set($scope, '$runtime.directive.money.unit', $attrs['unit'] || '' );
                    Flat.set($scope, '$runtime.directive.money.a', !!ui_sref);
                    Flat.set($scope, '$runtime.directive.money.span', !ui_sref);
                    Flat.set($scope, '$runtime.directive.money.ifClass', !isNaN(amount));
                    var if_class = "{'" + $attrs['class'] + "': $runtime.directive.money.ifClass}";

                    var html = '';
                    html += '<span>';
                    html += '   <em class="cny" ng-show="$runtime.directive.money.span"></em>';
                    html += '   <span class="amount" ng-if="$runtime.directive.money.a" ng-class="' + if_class+ '" ng-bind-html="' + key + '"></span>';
                    html += '   <span class="amount" ng-if="$runtime.directive.money.span" ng-class="' + if_class+ '" ng-bind-html="' + key + '"></span>';
                    html += '   <em class="unit-cny" ng-show="$runtime.directive.money.unit">{{$runtime.directive.money.unit}}</em>';
                    html += '</span>';

                    $ele.replaceWith($compile(html)($scope));
                }

                $scope.$watch(key, function(new_value){
                    show(key, Number(new_value));
                });

            }
        };
    }]);
